@@ -5,7 +5,7 @@
   
   DESCRIPTION:
   
-  $Id: regression-storage.c 620 2007-08-28 15:09:06Z rburton $
+  $Id: regression-storage.c 633 2008-02-18 07:26:45Z pchen $
   $Locker$
 
   (C) COPYRIGHT 1999 Eric Busboom 
@@ -145,6 +145,7 @@ void test_fileset_extended(void)
     int count=0;
     struct icaltimetype start, end;
     icalcomponent *c,*clone, *itr;
+    char *temp1, *temp2;
     icalsetiter iter;
 
     start = icaltime_from_timet( time(0),0);
@@ -221,9 +222,14 @@ void test_fileset_extended(void)
       dtstart = icalcomponent_get_first_property(event,ICAL_DTSTART_PROPERTY);
       dtend = icalcomponent_get_first_property(event,ICAL_DTEND_PROPERTY);
       
-      if (VERBOSE)
-	printf("%d %s %s\n",count, icalproperty_as_ical_string(dtstart),
-	       icalproperty_as_ical_string(dtend));
+      if (VERBOSE) {
+	temp1 = icalproperty_as_ical_string (dtstart);
+	temp2 = icalproperty_as_ical_string (dtend);
+	
+	printf("%d %s %s\n",count, temp1, temp2);
+	free (temp1);
+	free (temp2);
+      }
 
     }
 
@@ -270,9 +276,12 @@ void test_fileset_extended(void)
 
       dtstart = icalcomponent_get_first_property(event,ICAL_DTSTART_PROPERTY);
       dtend = icalcomponent_get_first_property(event,ICAL_DTEND_PROPERTY);
-      
-      printf("%d %s %s\n",count, icalproperty_as_ical_string(dtstart),
-             icalproperty_as_ical_string(dtend));
+     
+      temp1 = icalproperty_as_ical_string (dtstart) ;
+      temp2 = icalproperty_as_ical_string (dtend);
+      printf("%d %s %s\n",count, temp1, temp2);
+      free (temp1);
+      free (temp2);
 
     }
 
@@ -300,7 +309,7 @@ void test_bdbset()
     int num_components=0;
     int szdata_len=0;
     int ret=0;
-    char *subdb, *szdata, *szpacked_data;
+    char *subdb, *szdata, *szpacked_data, *temp1, *temp2;
     char uid[255];
     struct icaltimetype start, end;
     icalcomponent *c,*clone, *itr;
@@ -424,8 +433,11 @@ void test_bdbset()
       dtstart = icalcomponent_get_first_property(event,ICAL_DTSTART_PROPERTY);
       dtend = icalcomponent_get_first_property(event,ICAL_DTEND_PROPERTY);
       
-      printf("%d %s %s\n",count, icalproperty_as_ical_string(dtstart),
-             icalproperty_as_ical_string(dtend));
+      temp1 = icalproperty_as_ical_string (dtstart);
+      temp2 = icalproperty_as_ical_string (dtend);
+      printf("%d %s %s\n",count, temp1, temp2);
+      free (temp1);
+      free (temp2);
 
       }
       icalset_free(cout);
@@ -475,8 +487,11 @@ void test_bdbset()
       dtstart = icalcomponent_get_first_property(event,ICAL_DTSTART_PROPERTY);
       dtend = icalcomponent_get_first_property(event,ICAL_DTEND_PROPERTY);
       
-      printf("%d %s %s\n",count, icalproperty_as_ical_string(dtstart),
-             icalproperty_as_ical_string(dtend));
+      temp1 = icalproperty_as_ical_string (dtstart);
+      temp2 = icalproperty_as_ical_string (dtend);
+      printf("%d %s %s\n",count, temp1, temp2);
+      free (temp1);
+      free (temp2);
 
       }
       icalset_free(cout);
@@ -745,8 +760,11 @@ void test_dirset_extended(void)
 	    ok("Setting DTEND property", (icalerrno == ICAL_NO_ERROR));
 	    assert(icalerrno  == ICAL_NO_ERROR);
 	    
-	    if (VERBOSE)
-	      printf("\n----------\n%s\n---------\n",icalcomponent_as_ical_string(inner));
+	    if (VERBOSE) {
+	      	char *obj = icalcomponent_as_ical_string (inner);
+		printf("\n----------\n%s\n---------\n",icalcomponent_as_ical_string(inner));
+		free (obj);
+	    }
 
 	    error = icaldirset_add_component(s,
 					     icalcomponent_new_clone(itr));
@@ -769,7 +787,9 @@ void test_dirset_extended(void)
 	printf("Got one! (%d)\n", count++);
 	
 	if (c != 0){
-	    printf("%s", icalcomponent_as_ical_string(c));;
+	    char *obj = icalcomponent_as_ical_string (c);
+	    printf("%s", obj);;
+	    free (obj);
 	    if (icaldirset_add_component(s2,c) == 0){
 		printf("Failed to write!\n");
 	    }
@@ -786,7 +806,9 @@ void test_dirset_extended(void)
 	c = icaldirset_get_next_component(s)){
 
 	if (c != 0){
-	    printf("%s", icalcomponent_as_ical_string(c));;
+	    char *obj = icalcomponent_as_ical_string (c);
+	    printf("%s", obj);
+	    free (obj);
 	} else {
 	    printf("Failed to get component\n");
 	}
