@@ -7,7 +7,7 @@
  *  Bertrand Guiheneuf <bertrand@helixcode.com>
  *  Jeffrey Stedfast <fejj@ximian.com>
  *
- * Copyright 1999, 2000 Ximian, Inc. (www.ximian.com)
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -129,7 +129,8 @@ typedef enum {
 	CAMEL_PROVIDER_CONF_CHECKSPIN,
 	CAMEL_PROVIDER_CONF_ENTRY,
 	CAMEL_PROVIDER_CONF_LABEL,
-	CAMEL_PROVIDER_CONF_HIDDEN
+	CAMEL_PROVIDER_CONF_HIDDEN,
+	CAMEL_PROVIDER_CONF_OPTIONS
 } CamelProviderConfType;
 
 typedef struct {
