@@ -171,7 +171,7 @@ camel_groupwise_summary_new (struct _CamelFolder *folder, const char *filename)
 
 	camel_exception_init (&ex);
 	if (camel_folder_summary_load_from_db (summary, &ex) == -1) {
-		camel_folder_summary_clear (summary);
+		camel_folder_summary_clear_db (summary);
 	}
 
 	return summary;
@@ -387,13 +387,14 @@ gw_info_set_flags (CamelMessageInfo *info, guint32 flags, guint32 set)
 				if ((flags & CAMEL_MESSAGE_DELETED) && !(old & CAMEL_MESSAGE_DELETED)) {
 						mi->summary->deleted_count ++ ;
 
-						#warning "What to do when the user has set to show-deleted-messages "
+						/* FIXME[disk-summary] What to do when the user has set to show-deleted-messages */
 						mi->summary->visible_count -- ;
 
 						if (!(flags & CAMEL_MESSAGE_SEEN))
 							mi->summary->unread_count -- ;
 				}
 
+				mi->dirty = TRUE;
 				camel_folder_summary_touch(mi->summary);
 		}
 	}
@@ -489,7 +490,7 @@ groupwise_summary_clear (CamelFolderSummary *summary, gboolean uncache)
 		camel_message_info_free(info);
 	}
 
-	camel_folder_summary_clear (summary);
+	camel_folder_summary_clear_db (summary);
 	//camel_folder_summary_save (summary);
 
 	if (uncache)
