@@ -65,7 +65,6 @@ static int local_summary_load(CamelLocalSummary *cls, int forceindex, CamelExcep
 static int local_summary_check(CamelLocalSummary *cls, CamelFolderChangeInfo *changeinfo, CamelException *ex);
 static int local_summary_sync(CamelLocalSummary *cls, gboolean expunge, CamelFolderChangeInfo *changeinfo, CamelException *ex);
 static CamelMessageInfo *local_summary_add(CamelLocalSummary *cls, CamelMimeMessage *msg, const CamelMessageInfo *info, CamelFolderChangeInfo *, CamelException *ex);
-static int local_summary_need_index(void);
 
 static void camel_local_summary_class_init (CamelLocalSummaryClass *klass);
 static void camel_local_summary_init       (CamelLocalSummary *obj);
@@ -112,7 +111,6 @@ camel_local_summary_class_init(CamelLocalSummaryClass *klass)
 
 	klass->encode_x_evolution = local_summary_encode_x_evolution;
 	klass->decode_x_evolution = local_summary_decode_x_evolution;
-	klass->need_index = local_summary_need_index;
 }
 
 static void
@@ -162,7 +160,7 @@ camel_local_summary_load(CamelLocalSummary *cls, int forceindex, CamelException
 {
 	d(printf("Loading summary ...\n"));
 
-	if ((forceindex && ((CamelLocalSummaryClass *)(CAMEL_OBJECT_GET_CLASS(cls)))->need_index())
+	if (forceindex
 	    || ((CamelLocalSummaryClass *)(CAMEL_OBJECT_GET_CLASS(cls)))->load(cls, forceindex, ex) == -1) {
 		w(g_warning("Could not load summary: flags may be reset"));
 		camel_folder_summary_clear((CamelFolderSummary *)cls);
@@ -424,11 +422,6 @@ local_summary_sync(CamelLocalSummary *cls, gboolean expunge, CamelFolderChangeIn
 	return ret;
 }
 
-static int
-local_summary_need_index(void) {
-	return 1;
-}
-
 static void
 update_summary (CamelFolderSummary *summary, CamelMessageInfoBase *info, CamelMessageInfoBase *old)
 {
@@ -491,7 +484,6 @@ local_summary_add(CamelLocalSummary *cls, CamelMimeMessage *msg, const CamelMess
 			
 			update_summary (s, (CamelMessageInfoBase *) mi, (CamelMessageInfoBase *) info);
 			mi->info.flags |= (camel_message_info_flags(info) & 0xffff);
-			camel_folder_summary_update_flag_cache (s, mi->info.uid, mi->info.flags);
 			mi->info.size = camel_message_info_size(info);
 		}
 
